ConfigError

Enum ConfigError 

#[non_exhaustive]
pub enum ConfigError { ParseError { field: String, raw_display: String, expected_type: String, source: Box<dyn Error + Send + Sync>, }, FileError { path: PathBuf, source: Box<dyn Error + Send + Sync>, }, EnvVar { key: String, cause: String, }, FieldConflict { field: String, a: Source, b: Source, }, MissingRequired { field: String, }, Internal { message: String, }, }
All errors that cistell-core can produce.

#[non_exhaustive] so we can add variants in minor versions without breaking downstream match arms.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


ParseError

A value could not be parsed into the expected type.

Fields

field: String
raw_display: String

The raw value (or "<secret>" if the field is secret).

expected_type: String
source: Box<dyn Error + Send + Sync>


FileError

A config file could not be read or parsed.

Fields

path: PathBuf
source: Box<dyn Error + Send + Sync>


EnvVar

An environment variable exists but is not valid UTF-8.

Fields

cause: String


FieldConflict

Two sources at the same rank provide conflicting values.

Fields

field: String


MissingRequired

A required field has no default and no source provided a value.

Fields

field: String


Internal

An internal invariant was violated (should never happen in normal operation).

Fields

message: String

Implementations

Source

impl ConfigError

pub fn parse<E>(meta: &FieldMeta, raw: &str, source: E) -> Self
where E: Error + Send + Sync + 'static,

Create a ParseError, automatically redacting the raw value when meta.is_secret.